ListenerRequest

Enum ListenerRequest 

pub enum ListenerRequest {
    NotifyOnFirstUpdateCheck {
        payload: ListenerNotifyOnFirstUpdateCheckRequest,
        control_handle: ListenerControlHandle,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: ListenerControlHandle, method_type: MethodType, }, }
Used by components to wait for the first software update check to complete.

Variants



NotifyOnFirstUpdateCheck

Subscribe for a notification when the software update checker has completed its post-boot check (with or without error) and is not trying to reboot. If the update checker will never perform an update check, then it will close the connection with epitaph ZX_ERR_NOT_SUPPORTED and close the notifier connection without calling [fuchsia.update/Notifier.Notify].



#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

control_handle: ListenerControlHandle
method_type: MethodType

Implementations