pub enum ManagerRequest {
CheckNow {
options: CheckOptions,
monitor: Option<ClientEnd<MonitorMarker>>,
responder: ManagerCheckNowResponder,
},
PerformPendingReboot {
responder: ManagerPerformPendingRebootResponder,
},
MonitorAllUpdateChecks {
attempts_monitor: ClientEnd<AttemptsMonitorMarker>,
control_handle: ManagerControlHandle,
},
}Expand description
The Manager protocol is used by a client that wishes to either check for an update, or follow the status of ongoing updates.
The Manager provides a mechanism for checking for updates via the
[Manager.CheckNow] message.
Variants
CheckNow
Immediately check for an update, and optionally track the state and progress of that update check.
-
request
optionsOptions for how this request should be performed. E.g. What kind of entity initiated this request? E.g. Is monitoring an existing update check that is already in process an acceptable alternative? -
request
monitorAn interface on which to receive the status events for this update check. The monitor is only valid for this single update check, after that it will not receive any more notifications and will be closed.
- error If an update check cannot be started, an error will be returned.
The [
Monitor], if provided, will not receive any notifications.
Fields
options: CheckOptionsmonitor: Option<ClientEnd<MonitorMarker>>responder: ManagerCheckNowResponderPerformPendingReboot
Performs any pending reboot of the system into an updated OS, if an update has been staged for the next system startup.
Replaced by
fuchsia.power/CollaborativeRebootInitiator.PerformPendingReboot.
Fields
responder: ManagerPerformPendingRebootResponderMonitorAllUpdateChecks
Monitor all update attempts as they start, as well as an in-progress attempt, if there is one.
Arguments:
- |attempts_monitor| A protocol on which to receive |Monitor| instances as update attempts start.
Implementations
Sourceimpl ManagerRequest
impl ManagerRequest
pub fn into_check_now( self, ) -> Option<(CheckOptions, Option<ClientEnd<MonitorMarker>>, ManagerCheckNowResponder)>
pub fn into_perform_pending_reboot( self, ) -> Option<ManagerPerformPendingRebootResponder>
pub fn into_monitor_all_update_checks( self, ) -> Option<(ClientEnd<AttemptsMonitorMarker>, ManagerControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL