CheckOptions

Struct CheckOptions 

pub struct CheckOptions {
    pub initiator: Option<Initiator>,
    pub allow_attaching_to_existing_update_check: Option<bool>,
    /* private fields */
}
Configuration options for an update check.

Fields

initiator: Option<Initiator>

Who or what initiated this update attempt. This is taken as input to Policy, and may influence how the update check is performed.

This is a required field.

allow_attaching_to_existing_update_check: Option<bool>

If an update check is already in progress, it’s acceptable to instead attach a Monitor to that in-progress update instead of failing this request to check for updates. This may convert situations that would have resulted in the ALREADY_IN_PROGRESS to be treated as non-error cases.