pub struct ManagerProxy { /* private fields */ }Implementations
Sourceimpl ManagerProxy
impl ManagerProxy
Sourcepub fn take_event_stream(&self) -> ManagerEventStream
pub fn take_event_stream(&self) -> ManagerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn check_now(
&self,
options: &CheckOptions,
monitor: Option<ClientEnd<MonitorMarker>>,
) -> QueryResponseFut<ManagerCheckNowResult, DefaultFuchsiaResourceDialect>
pub fn check_now( &self, options: &CheckOptions, monitor: Option<ClientEnd<MonitorMarker>>, ) -> QueryResponseFut<ManagerCheckNowResult, DefaultFuchsiaResourceDialect>
Immediately check for an update, and optionally track the state and progress of that update check.
-
request
optionsOptions for how this request should be performed. E.g. What kind of entity initiated this request? E.g. Is monitoring an existing update check that is already in process an acceptable alternative? -
request
monitorAn interface on which to receive the status events for this update check. The monitor is only valid for this single update check, after that it will not receive any more notifications and will be closed.
- error If an update check cannot be started, an error will be returned.
The [
Monitor], if provided, will not receive any notifications.
Sourcepub fn perform_pending_reboot(
&self,
) -> QueryResponseFut<bool, DefaultFuchsiaResourceDialect>
pub fn perform_pending_reboot( &self, ) -> QueryResponseFut<bool, DefaultFuchsiaResourceDialect>
Performs any pending reboot of the system into an updated OS, if an update has been staged for the next system startup.
Replaced by
fuchsia.power/CollaborativeRebootInitiator.PerformPendingReboot.
Sourcepub fn monitor_all_update_checks(
&self,
attempts_monitor: ClientEnd<AttemptsMonitorMarker>,
) -> Result<(), Error>
pub fn monitor_all_update_checks( &self, attempts_monitor: ClientEnd<AttemptsMonitorMarker>, ) -> Result<(), Error>
Monitor all update attempts as they start, as well as an in-progress attempt, if there is one.
Arguments:
- |attempts_monitor| A protocol on which to receive |Monitor| instances as update attempts start.